@@ -200,8 +200,8 @@ class Google(callbacks.PluginRegexp):
         except google.NoLicenseKey, e:
             irc.error('You must have a free Google web services license key '
                       'in order to use this command.  You can get one at '
-                      '<http://google.com/apis/>.  Once you have one, you can '
-                      'set it with the command '
+                      '<http://code.google.com/apis/soapsearch/>.  Once you '
+                      'have one, you can set it with the command '
                       '"config supybot.plugins.Google.licenseKey <key>".')
             return
         bold = self.registryValue('bold', msg.args[0])
@@ -367,10 +367,10 @@ class Google(callbacks.PluginRegexp):
         url = r'http://google.com/search?q=' + s
         return url
 
-    _calcRe = re.compile(r'<td nowrap><font size=\+1><b>(.*?)</b>', re.I)
+    _calcRe = re.compile(r'<font size=\+1><b>(.*?)</b>', re.I)
     _calcSupRe = re.compile(r'<sup>(.*?)</sup>', re.I)
     _calcFontRe = re.compile(r'<font size=-2>(.*?)</font>')
-    _calcTimesRe = re.compile(r'&times;')
+    _calcTimesRe = re.compile(r'&(?:times|#215);')
     def calc(self, irc, msg, args, expr):
         """<expression>
 
@@ -412,4 +412,4 @@ class Google(callbacks.PluginRegexp):
 Class = Google
 
 
-# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
+# vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
