@@ -43,7 +43,7 @@ _pluginsDir = os.path.join(installDir, 'plugins')
 ###
 # version: This should be pretty obvious.
 ###
-version = '0.83.1'
+version = '0.83.3'
 
 ###
 # *** The following variables are affected by command-line options.  They are
@@ -259,7 +259,7 @@ class SpaceSeparatedSetOfChannels(registry.SpaceSeparatedListOf):
         else:
             return ircmsgs.join(channel)
 
-def registerNetwork(name, password=''):
+def registerNetwork(name, password='', ssl=False):
     network = registerGroup(supybot.networks, name)
     registerGlobalValue(network, 'password', registry.String(password,
         """Determines what password will be used on %s.  Yes, we know that
@@ -271,7 +271,7 @@ def registerNetwork(name, password=''):
         completed.""" % name))
     registerGlobalValue(network, 'channels', SpaceSeparatedSetOfChannels([],
         """Determines what channels the bot will join only on %s.""" % name))
-    registerGlobalValue(network, 'ssl', registry.Boolean(False,
+    registerGlobalValue(network, 'ssl', registry.Boolean(ssl,
         """Determines whether the bot will attempt to connect with SSL sockets
         to %s.""" % name))
     registerChannelValue(network.channels, 'key', registry.String('',
@@ -531,8 +531,8 @@ registerChannelValue(supybot.replies, 'requiresPrivacy',
     try to do things in a channel that really should be done in private."""))
 
 registerChannelValue(supybot.replies, 'possibleBug',
-    registry.NormalizedString("""This may
-    be a bug.  If you think it is, please file a bug report at
+    registry.NormalizedString("""This may be a bug.  If you think it is, please
+    file a bug report at
     <http://sourceforge.net/tracker/?func=add&group_id=58965&atid=489447>.""",
     """Determines what message the bot sends when it thinks you've encountered
     a bug that the developers don't know about."""))
@@ -669,11 +669,11 @@ class ValidDriverModule(registry.OnlySomeStrings):
 
 registerGlobalValue(supybot.drivers, 'module',
     ValidDriverModule('default', """Determines what driver module the bot will
-    use.  socketDrivers, a simple driver based on timeout sockets, is used by
-    default because it's simple and stable.  asyncoreDrivers is a bit older
-    (and less well-maintained) but allows you to integrate with asyncore-based
-    applications.  twistedDrivers is very stable and simple, and if you've got
-    Twisted installed, is probably your best bet."""))
+    use.  Socket, a simple driver based on timeout sockets, is used by default
+    because it's simple and stable.  Twisted is very stable and simple, and if
+    you've got Twisted installed, is probably your best bet.  If this setting
+    is left as default and Twisted-support is detected, the Twisted driver will
+    be used in favor of the Socket driver."""))
 
 registerGlobalValue(supybot.drivers, 'maxReconnectWait',
     registry.PositiveFloat(300.0, """Determines the maximum time the bot will
@@ -1024,4 +1024,4 @@ registerGlobalValue(supybot.debug, 'flushVeryOften',
     what's breaking or when, but think that it might be logged."""))
 
 
-# vim:set shiftwidth=4 tabstop=4 expandtab textwidth=79:
+# vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
