@@ -169,6 +169,30 @@ class ColorizedFormatter(Formatter):
         else:
             return Formatter.format(self, record, *args, **kwargs)
 
+conf.registerGlobalValue(conf.supybot.directories, 'log',
+    conf.Directory('logs', """Determines what directory the bot will store its
+    logfiles in."""))
+
+_logDir = conf.supybot.directories.log()
+if not os.path.exists(_logDir):
+    os.mkdir(_logDir, 0755)
+
+pluginLogDir = os.path.join(_logDir, 'plugins')
+
+if not os.path.exists(pluginLogDir):
+    os.mkdir(pluginLogDir, 0755)
+
+try:
+    messagesLogFilename = os.path.join(_logDir, 'messages.log')
+    _handler = BetterFileHandler(messagesLogFilename)
+except EnvironmentError, e:
+    raise SystemExit, \
+          'Error opening messages logfile (%s).  ' \
+          'Generally, this is because you are running Supybot in a directory ' \
+          'you don\'t have permissions to add files in, or you\'re running ' \
+          'Supybot as a different user than you normal do.  The original ' \
+          'error was: %s' % (messagesLogFilename, utils.gen.exnToString(e))
+
 # These are public.
 formatter = Formatter('NEVER SEEN; IF YOU SEE THIS, FILE A BUG!')
 pluginFormatter = PluginFormatter('NEVER SEEN; IF YOU SEE THIS, FILE A BUG!')
@@ -176,9 +200,11 @@ pluginFormatter = PluginFormatter('NEVER SEEN; IF YOU SEE THIS, FILE A BUG!')
 # These are not.
 logging.setLoggerClass(Logger)
 _logger = logging.getLogger('supybot')
+_stdoutHandler = StdoutStreamHandler(sys.stdout)
 
 class ValidLogLevel(registry.String):
     """Invalid log level."""
+    handler = None
     minimumLevel = -1
     def set(self, s):
         s = s.upper()
@@ -191,6 +217,8 @@ class ValidLogLevel(registry.String):
                 self.error()
         if level < self.minimumLevel:
             self.error()
+        if self.handler is not None:
+            self.handler.setLevel(level)
         self.setValue(level)
 
     def __str__(self):
@@ -204,13 +232,12 @@ class ValidLogLevel(registry.String):
 class LogLevel(ValidLogLevel):
     """Invalid log level.  Value must be either DEBUG, INFO, WARNING,
     ERROR, or CRITICAL."""
-    def setValue(self, v):
-        ValidLogLevel.setValue(self, v)
-        _logger.setLevel(self.value) # _logger defined later.
+    handler = _handler
 
-conf.registerGlobalValue(conf.supybot.directories, 'log',
-    conf.Directory('logs', """Determines what directory the bot will store its
-    logfiles in."""))
+class StdoutLogLevel(ValidLogLevel):
+    """Invalid log level.  Value must be either DEBUG, INFO, WARNING,
+    ERROR, or CRITICAL."""
+    handler = _stdoutHandler
 
 conf.registerGroup(conf.supybot, 'log')
 conf.registerGlobalValue(conf.supybot.log, 'format',
@@ -250,6 +277,10 @@ conf.registerGlobalValue(conf.supybot.log.stdout, 'format',
     """Determines what the bot's logging format will be.  The relevant
     documentation on the available formattings is Python's documentation on
     its logging module."""))
+conf.registerGlobalValue(conf.supybot.log.stdout, 'level',
+    StdoutLogLevel(logging.INFO, """Determines what the minimum priority level
+    logged will be.  Valid values are DEBUG, INFO, WARNING, ERROR, and
+    CRITICAL, in order of increasing priority."""))
 
 conf.registerGroup(conf.supybot.log, 'plugins')
 conf.registerGlobalValue(conf.supybot.log.plugins, 'individualLogfiles',
@@ -342,43 +373,24 @@ class MetaFirewall(type):
         #return type.__new__(cls, name, bases, dict)
 
 
-_logDir = conf.supybot.directories.log()
-if not os.path.exists(_logDir):
-    os.mkdir(_logDir, 0755)
-
-pluginLogDir = os.path.join(_logDir, 'plugins')
-
-if not os.path.exists(pluginLogDir):
-    os.mkdir(pluginLogDir, 0755)
-
-try:
-    messagesLogFilename = os.path.join(_logDir, 'messages.log')
-    _handler = BetterFileHandler(messagesLogFilename)
-except EnvironmentError, e:
-    raise SystemExit, \
-          'Error opening messages logfile (%s).  ' \
-          'Generally, this is because you are running Supybot in a directory ' \
-          'you don\'t have permissions to add files in, or you\'re running ' \
-          'Supybot as a different user than you normal do.  The original ' \
-          'error was: %s' % (messagesLogFilename, utils.gen.exnToString(e))
-_handler.setFormatter(formatter)
-_handler.setLevel(-1)
 class PluginLogFilter(logging.Filter):
     def filter(self, record):
         if conf.supybot.log.plugins.individualLogfiles():
             if record.name.startswith('supybot.plugins'):
                 return False
         return True
+
+_handler.setFormatter(formatter)
 _handler.addFilter(PluginLogFilter())
 
+_handler.setLevel(conf.supybot.log.level())
 _logger.addHandler(_handler)
-_logger.setLevel(conf.supybot.log.level())
+_logger.setLevel(-1)
 
+_stdoutFormatter = ColorizedFormatter('IF YOU SEE THIS, FILE A BUG!')
+_stdoutHandler.setFormatter(_stdoutFormatter)
+_stdoutHandler.setLevel(conf.supybot.log.stdout.level())
 if not conf.daemonized:
-    _stdoutHandler = StdoutStreamHandler(sys.stdout)
-    _stdoutFormatter = ColorizedFormatter('IF YOU SEE THIS, FILE A BUG!')
-    _stdoutHandler.setFormatter(_stdoutFormatter)
-    _stdoutHandler.setLevel(-1)
     _logger.addHandler(_stdoutHandler)
 
 
